@@ -1,4 +1,4 @@
-# (C) Copyright 2018-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2018-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,19 +14,24 @@ import unittest
 class TestApi(unittest.TestCase):
     def test_imports(self):
         from traits_futures.api import (  # noqa: F401
+            AsyncioEventLoop,
             BaseFuture,
+            BaseTask,
             CallFuture,
             CANCELLED,
             CANCELLING,
             COMPLETED,
+            ETSEventLoop,
             EXECUTING,
             ExecutorState,
             FAILED,
             FutureState,
+            IEventLoop,
             IFuture,
             IParallelContext,
             ITaskSpecification,
             IterationFuture,
+            MultiprocessingContext,
             MultithreadingContext,
             ProgressFuture,
             RUNNING,
@@ -35,6 +40,7 @@ class TestApi(unittest.TestCase):
             submit_call,
             submit_iteration,
             submit_progress,
+            TaskCancelled,
             TraitsExecutor,
             WAITING,
         )
